import { useState, useEffect } from 'react';
import { User } from '../types/auth';
import { Category, City } from '../types';
import { userService } from '../services/userService';

export function useUserManagement() {
  const [users, setUsers] = useState<User[]>([]);
  const [selectedUser, setSelectedUser] = useState<User | null>(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchUsers = async () => {
      try {
        setLoading(true);
        const fetchedUsers = await userService.getUsers();
        setUsers(fetchedUsers);
        setError(null);
      } catch (err) {
        setError('Failed to fetch users');
        console.error('Error fetching users:', err);
      } finally {
        setLoading(false);
      }
    };

    fetchUsers();
  }, []);

  const handlePermissionChange = async (
    category: Category,
    action: 'create' | 'edit' | 'delete',
    value: boolean
  ) => {
    if (!selectedUser) return;

    try {
      const updatedPermissions = {
        ...selectedUser.permissions,
        categories: {
          ...selectedUser.permissions.categories,
          [category.name]: {
            ...selectedUser.permissions.categories[category.name],
            [action]: value,
          },
        },
      };

      const updatedUser = await userService.updateUserPermissions(
        selectedUser.id,
        updatedPermissions
      );

      setSelectedUser(updatedUser);
      setUsers(users.map((user) => 
        user.id === selectedUser.id ? updatedUser : user
      ));
      setError(null);
    } catch (err) {
      setError('Failed to update permissions');
      console.error('Error updating permissions:', err);
    }
  };

  const handleCityChange = async (city: City, checked: boolean) => {
    if (!selectedUser) return;

    try {
      const updatedCities = checked
        ? [...selectedUser.permissions.cities, city]
        : selectedUser.permissions.cities.filter((c) => c !== city);

      const updatedPermissions = {
        ...selectedUser.permissions,
        cities: updatedCities,
      };

      const updatedUser = await userService.updateUserPermissions(
        selectedUser.id,
        updatedPermissions
      );

      setSelectedUser(updatedUser);
      setUsers(users.map((user) => 
        user.id === selectedUser.id ? updatedUser : user
      ));
      setError(null);
    } catch (err) {
      setError('Failed to update city permissions');
      console.error('Error updating city permissions:', err);
    }
  };

  return {
    users,
    selectedUser,
    loading,
    error,
    setSelectedUser,
    handlePermissionChange,
    handleCityChange
  };
}