import React, { useState, useMemo, useEffect } from 'react';
import axios from "axios";
import { useEditor, EditorContent } from '@tiptap/react';
import StarterKit from '@tiptap/starter-kit';
import { Header } from '../components/Header';
import { GalleryManager } from '../components/GalleryManager';
import { CoverImageUpload } from '../components/ImageUpload/CoverImageUpload';
import {Category, City, Article, GalleryImage, CategoryMap} from '../types';
import { Bold, Italic, List, ListOrdered, Quote, Pencil, Trash2, ChevronLeft, ChevronRight } from 'lucide-react';
import { articles } from '../data/mock';

//const categories: Category[] = ['Film', 'Theater', 'Music', 'Sports', 'Art', 'Legends', 'Anniversaries', 'Memory'];
const categories: Category[] = ['Кино', 'Театр', 'Музыка', 'Спорт', 'Искусство', 'Легенды', 'Юбилеи', 'Память'];

/*
const categorieIds: Category[] = CategoryNames.map((name, index) => ({
  id: index + 1,
  name,
}));
*/


const cities: City[] = ['New York', 'London'];
const ARTICLES_PER_PAGE = 5;

export function AdminPage() {
  const [title, setTitle] = useState('');
  const [excerpt, setExcerpt] = useState('');
  const [category, setCategory] = useState<Category>('Искусство');
  const [city, setCity] = useState<City>('New York');
  const [coverImage, setCoverImage] = useState('');
  const [readTime, setReadTime] = useState(5);
  const [gallery, setGallery] = useState<GalleryImage[]>([]);
  const [editingId, setEditingId] = useState<string | null>(null);
  const [showDeleteModal, setShowDeleteModal] = useState<string | null>(null);
  const [articlesList, setArticlesList] = useState(articles);
  const [currentPage, setCurrentPage] = useState(1);
  const [filterCategory, setFilterCategory] = useState<Category | ''>('');
  const [filterCity, setFilterCity] = useState<City | ''>('');
  const [error, setError] = useState<string | null>(null);

  const editor = useEditor({
    extensions: [StarterKit],
    content: '',
    editorProps: {
      attributes: {
        class: 'prose prose-lg focus:outline-none min-h-[300px] max-w-none',
      },
    },
  });

/*
  useEffect(() => {
    async function fetchArticles() {
      try {
        const response = await axios.get('/api/articles', {
          headers: {
            Authorization: `Bearer ${localStorage.getItem('token')}`,
          },
        });
        setArticlesList(response.data);
      } catch (err) {
        setError('Не удалось загрузить статьи');
        console.error(err);
      }
    }
    fetchArticles();
  }, []);
*/

  const filteredArticles = useMemo(() => {
    return articlesList.filter(article => {
      if (filterCategory && filterCity) {
        return article.category === filterCategory && article.city === filterCity;
      }
      if (filterCategory) {
        return article.category === filterCategory;
      }
      if (filterCity) {
        return article.city === filterCity;
      }
      return true;
    });
  }, [articlesList, filterCategory, filterCity]);

  const totalPages = Math.ceil(filteredArticles.length / ARTICLES_PER_PAGE);
  const paginatedArticles = useMemo(() => {
    const startIndex = (currentPage - 1) * ARTICLES_PER_PAGE;
    return filteredArticles.slice(startIndex, startIndex + ARTICLES_PER_PAGE);
  }, [filteredArticles, currentPage]);

  const handlePageChange = (page: number) => {
    setCurrentPage(page);
  };

  const handleEdit = (id: string) => {
    const article = articlesList.find(a => a.id === id);
    if (article) {
      setTitle(article.title);
      setExcerpt(article.excerpt);
      setCategory(article.category);
      setCity(article.city);
      setCoverImage(article.coverImage);
      setReadTime(article.readTime);
      setGallery(article.gallery || []);
      editor?.commands.setContent(article.content);
      setEditingId(id);
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }
  };

  const handleDelete = (id: string) => {
    setArticlesList(prev => prev.filter(article => article.id !== id));
    setShowDeleteModal(null);
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();

    const categoryId : number = CategoryMap[category];
    if (!categoryId) {
      console.error('Invalid category name.');
      return;
    }

    const articleData = {
      title,
      excerpt,
      categoryId,
      city,
      coverImage,
      readTime,
      gallery,
      content: editor?.getHTML() || '',
    };

    if (editingId) {
      setArticlesList(prev =>
          prev.map(article =>
              article.id === editingId
                  ? {...article, ...articleData}
                  : article
          )
      );
      setEditingId(null);
    } else {
      // Создание новой статьи
      const response = await axios.post('/api/articles', articleData, {
        headers: {
          Authorization: `Bearer ${localStorage.getItem('token')}`,
        },
      });
      setArticlesList(prev => [...prev, response.data]);

      // In a real app, this would send data to an API
      console.log('Creating new article:', articleData);
    }

    // Reset form
    setTitle('');
    setExcerpt('');
    setCategory('Art');
    setCity('New York');
    setCoverImage('');
    setReadTime(5);
    setGallery([]);
    editor?.commands.setContent('');
  };

  return (
    <div className="min-h-screen bg-gray-50">
      <Header />
      <main className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="bg-white rounded-lg shadow-sm p-6 mb-8">
          <h1 className="text-2xl font-bold text-gray-900 mb-6">
            {editingId ? 'Редактировать статью' : 'Создать новую статью'}
          </h1>
          
          {error && (
            <div className="mb-6 bg-red-50 text-red-700 p-4 rounded-md">
              {error}
            </div>
          )}
          
          <form onSubmit={handleSubmit} className="space-y-6">
            <div>
              <label htmlFor="title" className="block text-sm font-medium text-gray-700">
                Заголовок
              </label>
              <input
                type="text"
                id="title"
                value={title}
                onChange={(e) => setTitle(e.target.value)}
                className="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
                required
              />
            </div>

            <div>
              <label htmlFor="excerpt" className="block text-sm font-medium text-gray-700">
                Краткое описание
              </label>
              <textarea
                id="excerpt"
                rows={3}
                value={excerpt}
                onChange={(e) => setExcerpt(e.target.value)}
                className="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
                required
              />
            </div>

            <div className="grid grid-cols-1 gap-6 sm:grid-cols-3">
              <div>
                <label htmlFor="category" className="block text-sm font-medium text-gray-700">
                  Категория
                </label>
                <select
                  id="category"
                  value={category}
                  onChange={(e) => setCategory(e.target.value as Category)}
                  className="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
                >
                  {categories.map((cat) => (
                    <option key={cat} value={cat}>
                      {cat}
                    </option>
                  ))}
                </select>
              </div>

              <div>
                <label htmlFor="city" className="block text-sm font-medium text-gray-700">
                  Город
                </label>
                <select
                  id="city"
                  value={city}
                  onChange={(e) => setCity(e.target.value as City)}
                  className="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
                >
                  {cities.map((c) => (
                    <option key={c} value={c}>
                      {c}
                    </option>
                  ))}
                </select>
              </div>

              <div>
                <label htmlFor="readTime" className="block text-sm font-medium text-gray-700">
                  Время чтения (минуты)
                </label>
                <input
                  type="number"
                  id="readTime"
                  min="1"
                  value={readTime}
                  onChange={(e) => setReadTime(Number(e.target.value))}
                  className="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
                />
              </div>
            </div>

            <CoverImageUpload
              coverImage={coverImage}
              onImageUpload={setCoverImage}
              onError={setError}
            />

            <div>
              <label className="block text-sm font-medium text-gray-700">
                Статья
              </label>
              <div className="border rounded-lg overflow-hidden">
                <div className="border-b bg-gray-50 px-4 py-2">
                  <div className="flex items-center space-x-4">
                    <button
                      type="button"
                      onClick={() => editor?.chain().focus().toggleBold().run()}
                      className={`p-1 rounded hover:bg-gray-200 ${
                        editor?.isActive('bold') ? 'bg-gray-200' : ''
                      }`}
                    >
                      <Bold size={18} />
                    </button>
                    <button
                      type="button"
                      onClick={() => editor?.chain().focus().toggleItalic().run()}
                      className={`p-1 rounded hover:bg-gray-200 ${
                        editor?.isActive('italic') ? 'bg-gray-200' : ''
                      }`}
                    >
                      <Italic size={18} />
                    </button>
                    <button
                      type="button"
                      onClick={() => editor?.chain().focus().toggleBulletList().run()}
                      className={`p-1 rounded hover:bg-gray-200 ${
                        editor?.isActive('bulletList') ? 'bg-gray-200' : ''
                      }`}
                    >
                      <List size={18} />
                    </button>
                    <button
                      type="button"
                      onClick={() => editor?.chain().focus().toggleOrderedList().run()}
                      className={`p-1 rounded hover:bg-gray-200 ${
                        editor?.isActive('orderedList') ? 'bg-gray-200' : ''
                      }`}
                    >
                      <ListOrdered size={18} />
                    </button>
                    <button
                      type="button"
                      onClick={() => editor?.chain().focus().toggleBlockquote().run()}
                      className={`p-1 rounded hover:bg-gray-200 ${
                        editor?.isActive('blockquote') ? 'bg-gray-200' : ''
                      }`}
                    >
                      <Quote size={18} />
                    </button>
                  </div>
                </div>
                <div className="p-4">
                  <EditorContent editor={editor} />
                </div>
              </div>
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-700 mb-4">
                Фото Галерея
              </label>
              <GalleryManager
                images={gallery}
                onChange={setGallery}
              />
            </div>

            <div className="flex justify-end gap-4">
              {editingId && (
                <button
                  type="button"
                  onClick={() => {
                    setEditingId(null);
                    setTitle('');
                    setExcerpt('');
                    setCategory('Искусство');
                    setCity('New York');
                    setCoverImage('');
                    setReadTime(5);
                    setGallery([]);
                    editor?.commands.setContent('');
                  }}
                  className="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
                >
                  Отмена
                </button>
              )}
              <button
                type="submit"
                className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
              >
                {editingId ? 'Изменить статью' : 'Опубликовать статью'}
              </button>
            </div>
          </form>
        </div>

        {/* Articles List */}
        <div className="bg-white rounded-lg shadow-sm">
          <div className="px-6 py-4 border-b border-gray-200">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <h2 className="text-lg font-medium text-gray-900">Опубликованные статьи</h2>
              <div className="flex gap-4">
                <select
                  value={filterCategory}
                  onChange={(e) => {
                    setFilterCategory(e.target.value as Category | '');
                    setCurrentPage(1);
                  }}
                  className="rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 text-sm"
                >
                  <option value="">Все категории</option>
                  {categories.map((cat) => (
                    <option key={cat} value={cat}>
                      {cat}
                    </option>
                  ))}
                </select>
                <select
                  value={filterCity}
                  onChange={(e) => {
                    setFilterCity(e.target.value as City | '');
                    setCurrentPage(1);
                  }}
                  className="rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 text-sm"
                >
                  <option value="">Все столицы</option>
                  {cities.map((c) => (
                    <option key={c} value={c}>
                      {c}
                    </option>
                  ))}
                </select>
              </div>
            </div>
          </div>

          <ul className="divide-y divide-gray-200">
            {paginatedArticles.map((article) => (
              <li key={article.id} className="px-6 py-4">
                <div className="flex items-center justify-between">
                  <div className="flex-1 min-w-0">
                    <h3 className="text-sm font-medium text-gray-900 truncate">
                      {article.title}
                    </h3>
                    <p className="text-sm text-gray-500">
                      {article.category} · {article.city} · {article.readTime} min read
                    </p>
                  </div>
                  <div className="flex items-center gap-4 ml-4">
                    <button
                      onClick={() => handleEdit(article.id)}
                      className="p-2 text-gray-400 hover:text-blue-600 rounded-full hover:bg-blue-50"
                    >
                      <Pencil size={18} />
                    </button>
                    <button
                      onClick={() => setShowDeleteModal(article.id)}
                      className="p-2 text-gray-400 hover:text-red-600 rounded-full hover:bg-red-50"
                    >
                      <Trash2 size={18} />
                    </button>
                  </div>
                </div>
              </li>
            ))}
          </ul>

          {/* Pagination */}
          {totalPages > 1 && (
            <div className="px-6 py-4 border-t border-gray-200">
              <div className="flex items-center justify-between">
                <div className="text-sm text-gray-500">
                  Showing {((currentPage - 1) * ARTICLES_PER_PAGE) + 1} to {Math.min(currentPage * ARTICLES_PER_PAGE, filteredArticles.length)} of {filteredArticles.length} articles
                </div>
                <div className="flex items-center space-x-2">
                  <button
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                    className="p-2 rounded-md text-gray-500 hover:text-gray-700 hover:bg-gray-100 disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    <ChevronLeft size={20} />
                  </button>
                  {Array.from({ length: totalPages }, (_, i) => i + 1).map((page) => (
                    <button
                      key={page}
                      onClick={() => handlePageChange(page)}
                      className={`px-4 py-2 text-sm font-medium rounded-md ${
                        currentPage === page
                          ? 'bg-blue-600 text-white'
                          : 'text-gray-700 hover:bg-gray-100'
                      }`}
                    >
                      {page}
                    </button>
                  ))}
                  <button
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                    className="p-2 rounded-md text-gray-500 hover:text-gray-700 hover:bg-gray-100 disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    <ChevronRight size={20} />
                  </button>
                </div>
              </div>
            </div>
          )}
        </div>
      </main>

      {/* Delete Confirmation Modal */}
      {showDeleteModal && (
        <div className="fixed inset-0 bg-gray-500 bg-opacity-75 flex items-center justify-center p-4">
          <div className="bg-white rounded-lg max-w-md w-full p-6">
            <h3 className="text-lg font-medium text-gray-900 mb-4">
              Delete Article
            </h3>
            <p className="text-sm text-gray-500 mb-6">
              Are you sure you want to delete this article? This action cannot be undone.
            </p>
            <div className="flex justify-end gap-4">
              <button
                onClick={() => setShowDeleteModal(null)}
                className="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50"
              >
                Cancel
              </button>
              <button
                onClick={() => handleDelete(showDeleteModal)}
                className="px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-red-600 hover:bg-red-700"
              >
                Delete
              </button>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}