import { Header } from '../components/Header';
import { AuthGuard } from '../components/AuthGuard';
import { Category, City } from '../types';
import { useUserManagement } from '../hooks/useUserManagement';

const categories: Category[] = [
  {id : 1, name : 'Film'},
  {id : 2, name : 'Theater'},
  {id : 3, name : 'Music'},
  {id : 4, name : 'Sports'},
  {id : 5, name : 'Art'},
  {id : 6, name : 'Legends'},
  {id : 7, name : 'Anniversaries'},
  {id : 8, name : 'Memory'}
];

const cities: City[] = ['New York', 'London'];

export function UserManagementPage() {
  const {
    users,
    selectedUser,
    loading,
    error,
    setSelectedUser,
    handlePermissionChange,
    handleCityChange
  } = useUserManagement();

  if (loading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-600"></div>
      </div>
    );
  }

  return (
    <AuthGuard>
      <div className="min-h-screen bg-gray-50">
        <Header />
        <main className="max-w-7xl mx-auto py-6 sm:px-6 lg:px-8">
          <div className="px-4 py-6 sm:px-0">
            <div className="flex justify-between items-center mb-8">
              <h1 className="text-2xl font-bold text-gray-900">
                Управление пользователями
              </h1>
              {error && (
                <div className="bg-red-50 text-red-700 px-4 py-2 rounded-md text-sm">
                  {error}
                </div>
              )}
            </div>

            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              {/* Users List */}
              <div className="bg-white rounded-lg shadow p-6">
                <h2 className="text-lg font-medium text-gray-900 mb-4">Пользователи</h2>
                <ul className="space-y-2">
                  {users.map((user) => (
                    <li key={user.id}>
                      <button
                        onClick={() => setSelectedUser(user)}
                        className={`w-full text-left px-4 py-2 rounded-md ${
                          selectedUser?.id === user.id
                            ? 'bg-blue-50 text-blue-700'
                            : 'hover:bg-gray-50'
                        }`}
                      >
                        <div className="font-medium">{user.displayName}</div>
                        <div className="text-sm text-gray-500">{user.email}</div>
                      </button>
                    </li>
                  ))}
                </ul>
              </div>

              {/* Permissions Editor */}
              {selectedUser && (
                <div className="md:col-span-2 bg-white rounded-lg shadow p-6">
                  <h2 className="text-lg font-medium text-gray-900 mb-4">
                    Редактирование прав пользователя "{selectedUser.displayName}"
                  </h2>

                  <div className="space-y-6">
                    {/* Categories Permissions */}
                    <div>
                      <h3 className="text-sm font-medium text-gray-700 mb-4">
                        Права по категориям
                      </h3>
                      <div className="space-y-4">
                        {categories.map((category) => (
                          <div key={category.id} className="border rounded-lg p-4">
                            <h4 className="font-medium mb-2">{category.name}</h4>
                            <div className="space-y-2">
                              {(['create', 'edit', 'delete'] as const).map((action) => (
                                <label
                                  key={action}
                                  className="flex items-center space-x-2"
                                >
                                  <input
                                    type="checkbox"
                                    checked={
                                      selectedUser.permissions.categories[category.name]?.[action] ?? false
                                    }
                                    onChange={(e) =>
                                      handlePermissionChange(
                                        category,
                                        action,
                                        e.target.checked
                                      )
                                    }
                                    className="rounded border-gray-300 text-blue-600 focus:ring-blue-500"
                                  />
                                  <span className="text-sm text-gray-700 capitalize">
                                    {action}
                                  </span>
                                </label>
                              ))}
                            </div>
                          </div>
                        ))}
                      </div>
                    </div>

                    {/* Cities Access */}
                    <div>
                      <h3 className="text-sm font-medium text-gray-700 mb-4">
                        Разрешения для города
                      </h3>
                      <div className="space-y-2">
                        {cities.map((city) => (
                          <label
                            key={city}
                            className="flex items-center space-x-2"
                          >
                            <input
                              type="checkbox"
                              checked={selectedUser.permissions.cities.includes(city)}
                              onChange={(e) =>
                                handleCityChange(city, e.target.checked)
                              }
                              className="rounded border-gray-300 text-blue-600 focus:ring-blue-500"
                            />
                            <span className="text-sm text-gray-700">{city}</span>
                          </label>
                        ))}
                      </div>
                    </div>
                  </div>
                </div>
              )}
            </div>
          </div>
        </main>
      </div>
    </AuthGuard>
  );
}